@@ -1,10 +1,10 @@
 #' @useDynLib batchtools fill_gaps
 readLog = function(id, missing.as.empty = FALSE, reg = getDefaultRegistry()) {
   log.file = getLogFiles(reg, id)
-  if (is.na(log.file) || !fs::file_exists(log.file)) {
+  if (is.na(log.file) || !waitForFile(log.file, timeout = reg$cluster.functions$fs.latency, must.work = FALSE)) {
     if (missing.as.empty)
       return(data.table(job.id = integer(0L), lines = character(0L)))
-    stopf("Log file for job with id %i not available", id$job.id)
+    stopf("Log file '%s' for job with id %i not available", log.file, id$job.id)
   }
 
   lines = readLines(log.file)
@@ -40,7 +40,7 @@ extractLog = function(log, id) {
 #' @template reg
 #' @export
 #' @family debug
-#' @return [\code{\link{data.table}}] with columns \dQuote{job.id} and \dQuote{message}.
+#' @return [\code{\link[data.table]{data.table}}] with columns \dQuote{job.id} and \dQuote{message}.
 grepLogs = function(ids = NULL, pattern, ignore.case = FALSE, fixed = FALSE, reg = getDefaultRegistry()) {
   assertRegistry(reg, sync = TRUE)
   assertString(pattern, min.chars = 1L)
