@@ -1,6 +1,6 @@
 #' @description
 #' For bug reports and feature requests please use the tracker:
-#' \url{https://github.com/mllg/batchtools}.
+#' \url{https://github.com/mlr-org/batchtools}.
 #'
 #' @section Package options:
 #' \describe{
@@ -19,8 +19,8 @@
 #' loading \pkg{batchtools}.
 #' @import utils
 #' @import checkmate
-#' @import data.table
 #' @import stringi
+#' @import data.table
 #' @importFrom R6 R6Class
 #' @importFrom digest digest
 #' @importFrom brew brew
@@ -31,22 +31,13 @@
 #' @importFrom withr with_dir with_seed local_options local_dir
 "_PACKAGE"
 
-#' @title Deprecated function in the batchtools package
-#' @rdname batchtools-deprecated
-#' @name batchtools-deprecated
-#' @description
-#' The following functions have been deprecated:
-#' \tabular{rl}{
-#'   \code{chunkIds} \tab deprecated in favor of \code{\link{chunk}}, \code{\link{lpt}} and \code{\link{binpack}}\cr
-#' }
-NULL
-
 batchtools = new.env(parent = emptyenv())
 batchtools$debug = FALSE
 batchtools$hooks = list(
   remote = c("pre.do.collection", "post.do.collection"),
   local  = c("pre.sync", "post.sync", "pre.submit.job", "post.submit.job", "pre.submit", "post.submit", "pre.kill", "post.kill")
 )
+
 batchtools$resources = list(
   per.job = c("walltime", "memory", "ncpus", "omp.threads", "blas.threads"),
   per.chunk = c("measure.memory", "chunks.as.arrayjobs", "pm.backend", "foreach.backend")
